@@ -1,5 +1,4 @@
 # almoststatic
-from audioop import reverse
 import datetime
 import os
 import copy
@@ -51,7 +50,7 @@ class Almoststatic():
         self.cache = True
         """bool: global enable or disable cache"""
 
-        self.quote_escape = '``'
+        self.quote_escape = '^^'
         """str: sequence for quote escape in markdown translation"""
 
         # ------------------------------------------------------ runtime fields
@@ -141,6 +140,7 @@ class Almoststatic():
         self.vars['get_media'] = self.get_media
         self.vars['include'] = self._import_file
         self.vars['embed'] = self.render_content
+        self.vars['particle'] = self.particle
         self.vars['get_url'] = self.get_url
         self.vars['query_blog'] = self.query_blog
         self.vars['pages_id'] = self.pages_id
@@ -181,8 +181,8 @@ class Almoststatic():
         if not page:
             return page
 
-        # if the page was already cached and newer the file it is not rendered
-        # again
+        # if the page was already cached and not newer the file it is not
+        # rendered again
         self.was_cached = False
         content = None
         if self.cache and page.get('cacheable', True):
@@ -257,7 +257,7 @@ class Almoststatic():
                 continue
             s = self.build_page(page)
             filename = os.path.join(
-                destination, page+self.env.globals['url_suffix'])
+                destination, page + self.env.globals['url_suffix'])
             os.makedirs(os.path.dirname(filename), exist_ok=True)
             with open(filename, "w") as f:
                 f.write(s)
@@ -336,7 +336,7 @@ class Almoststatic():
     def get_markdown(self, text):
         """convert markdown to html with tables extension.
 
-        double quote and single quotes by default can be escaped with "``"
+        double quote and single quotes by default can be escaped with "^^"
         sequence, this let to insert Jinja2 commands within links.
         In markdown `[My Page]({{get_url("mylink")}})` produce an error because
         markdown uses quotes to identify title attribute. So it can be
@@ -350,7 +350,7 @@ class Almoststatic():
         """
         quote_marker = '\\:'
         text = text.replace(self.quote_escape, quote_marker)
-        text = markdown.markdown(text, extensions=['tables'])
+        text = markdown.markdown(text, extensions=['tables', 'fenced_code'])
         return text.replace(quote_marker, "'")
 
     def _relative_url(self):
@@ -487,7 +487,7 @@ class Almoststatic():
         """
         base_path = os.path.join(self.content, self.pages, '')
         path = os.path.join(base_path, subfolder, '')
-        files = glob.glob(path+'**/*.yaml', recursive=True)
+        files = glob.glob(path + '**/*.yaml', recursive=True)
         pages = [s.replace(base_path, '').replace('.yaml', '') for s in files]
         return files, pages
 
@@ -543,7 +543,7 @@ class Almoststatic():
 
     def get_filename(self, pagename):
         """return the yaml file from pagename"""
-        return os.path.join(self.content, self.pages, pagename+'.yaml')
+        return os.path.join(self.content, self.pages, pagename + '.yaml')
 
     def render_content(self, content, widgets_envelope=None):
         """Render the content of page, the content is a a key of the page and
@@ -557,20 +557,38 @@ class Almoststatic():
             # each widgets must have a key 'type' which indicate the name of
             # template to render, if the type id 'include', a file of widgets
             # is included
-            if widget['type'] == 'include':
-                result += self._import_file(widget['file'])
-            else:
-                disabled = widget.get('disabled', False)
-                if not disabled:
+            disabled = widget.get('disabled', False)
+            if not disabled:
+                if widget['type'] == 'include':
+                    text = self._import_file(widget['file'])
+                else:
                     widget = self.eval_widget(widget)
                     text = self.render_template(
-                        widget['type']+'.html', widget=widget)
-                    envelope = widget.get('envelope') or widgets_envelope
-                    if envelope:
-                        text = "%s\n%s\n%s" % (envelope[0], text, envelope[1])
-                    result += text
+                        widget['type'] + '.html', widget=widget)
+                envelope = widget.get('envelope') or widgets_envelope
+                if envelope:
+                    text = "%s\n%s\n%s" % (envelope[0], text, envelope[1])
+                result += text
         return result
 
+    def particle(self, name, key='particles'):
+        """A particle is a widget that can be embedded everywhere into a a text
+        field. The widget is declared into page in a section called "particles"
+        or whatever you want, and the "id" field is used to select the widget
+        to render.
+
+        Args:
+            name (str): the id to search
+            key (str, optional): The section containing the particle to search.
+              Defaults to 'particles'.
+
+        Returns:
+            str: the rendered text
+        """
+        for content in self.page[key]:
+            if content['id'] == name:
+                return self.render_content(content)
+
     def eval_widget(self, value, key=''):
         """Eval a single widget searching for a 'text' key which contain the
         text render. If the text is a string it is always rendered as markdown,
